/************************************************************************/
/*  Routines to get information about the input stream.			*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: get_stream_info.c,v 1.4 2007/08/29 18:28:29 doug Exp $ ";
#endif

#include <stdio.h>
#include <stdlib.h>
#include <strings.h>

#include "qlib2.h"

#include "params.h"
#include "st_info.h"
#include "holdings.h"
#include "procs.h"
#include "externals.h"

/************************************************************************/
/*  get_stream_info:							*/
/*	Get information about the input data stream.			*/
/************************************************************************/
int get_stream_info 
   (ST_INFO	*st_p)		/* ptr to current stream header.	*/
{
    SDR_HDR	    *sh;
    DATA_HDR	    *hdr;
    char	    str[SDR_SEQ_LEN+1];
    int		    seq_no, next_seq;
    int		    i;
    int		    nb;
    int		    skip;

    if (fill_buffer (st_p, MAX_BLKSIZE) == 0) return (EOF);

    /*	Determine the type of the file, and fill in header information.	*/
    /*	Get: 
    /*	    header_type, station, stream, sample rate, and blksize.	*/

    st_p->hdr_type = get_header_type (st_p->iob->buf, st_p->iob->free);

    switch (st_p->hdr_type) {
    case SDR_HDR_TYPE:
	sh = (SDR_HDR *)(st_p->iob->buf);
	hdr = decode_hdr_sdr(sh,st_p->iob->free);
	strcpy (st_p->station, hdr->station_id);
	strcpy (st_p->channel, hdr->channel_id);
	strcpy (st_p->network, hdr->network_id);
	strcpy (st_p->location, hdr->location_id);
	st_p->rate = hdr->sample_rate;
	st_p->rate_mult = hdr->sample_rate_mult;
	st_p->blksize = hdr->blksize;
	free_data_hdr(hdr);
	if (st_p->blksize > MAX_BLKSIZE) {
	    fprintf(stderr, "Fatal Error, Block size %d is greater than MAX_BLKSIZE %d\n",
		    st_p->blksize, MAX_BLKSIZE);
	    exit(1);
	}
	if (st_p->blksize == 0) {
	    fprintf (stderr, "invalid blocksize for %s\n", st_p->filename);
	    exit(1);
	}
	break;

    default:
	fprintf (stderr, "unrecognizable input file %s\n", st_p->filename);
	exit(1);
	break;
    }
    return(0);
}

/************************************************************************/
/*  get_header_type:							*/
/*	Determine the type of stream.					*/
/************************************************************************/
int get_header_type 
   (char    *p,
    int	    nr)
{
    if (is_drm_header ((STORE_FILE_HEAD *)p,nr)) return DRM_HDR_TYPE;
    else if (is_qda_header ((QDA_HDR *)p,nr)) return QDA_HDR_TYPE;
    else if (is_sdr_header ((SDR_HDR *)p,nr)) return SDR_HDR_TYPE;
    else return (-1);
}
