/************************************************************************/
/*  Routines to create holding						*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996, 1999 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: make_holdings.c,v 1.3 2007/08/29 18:28:29 doug Exp $ ";
#endif

#include    <stdio.h>
#include    <strings.h>

#include    "qlib2.h"

#include    "params.h"
#include    "st_info.h"
#include    "holdings.h"
#include    "procs.h"
#include    "externals.h"

/************************************************************************/
/*  make_holdings:							*/
/*	Create holdings entry for the specified file.			*/
/************************************************************************/
int make_holdings 
    (char	*file)
{
    ST_INFO	*st_p;		/* ptr to input stream structure.	*/
    ST_INFO	*out_p;		/* ptr to output stream structure.	*/
    ST_INFO	*prev_stream;	/* ptr to prev input stream structure.	*/
    int		i;
    INT_TIME	*stime;
    INT_TIME	*etime;


    open_stream (&st_head_out, outfile, "w");
    open_stream (&st_head_in, file, "r");

    /*	Copy input filename to output structure for summary reference.	*/
    strcpy (st_head_out.next->filename, st_head_in.next->filename);

    /*	Determine the block size and format of the input stream.	*/
    st_p = st_head_in.next;
    if (get_stream_info (st_p) == EOF) {
	st_p = close_stream(st_p);
	return (0);
    }

    get_block_info (st_p);
    out_p = st_head_out.next;
    while (position_stream (st_p, NULL, NULL) >= 0) {
	/* Process the data in the current block.			*/
	process_block (st_p);
    }
    out_p->init_offset = st_p->init_offset;
    out_p->cur_offset = st_p->cur_offset;
    close_stream(st_p);
    flush_output(out_p);
    print_stream_summary(out_p);
    close_stream(out_p);
    return(0);
}
