/************************************************************************/
/*  Command line parsing routines.					*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: parse_cmdline.c,v 1.3 2001/08/09 20:48:00 doug Exp $ ";
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "qlib2.h"

#include "params.h"
#include "st_info.h"
#include "holdings.h"
#include "procs.h"
#include "externals.h"

#define	argc	(*pargc)
#define	argv	(*pargv)

/************************************************************************/
/*  parse_cmdline:							*/
/*	Parse command line.						*/
/************************************************************************/
int parse_cmdline 
   (int		*pargc,		/* ptr to argc.				*/
    char	***pargv)	/* ptr to argv.				*/
{
    /* Variables needed for getopt. */
    extern char	*optarg;
    extern int	optind, opterr;
    int		c;

    int i;
    int	nfiles;
    char    *p;

    cmdname = tail(*argv);
    ++no_output;

    /*	Parse command line options.					*/
    while ( (c = getopt(argc,argv,"hd:H:O:D:M:N:CSAm")) != -1)
	switch (c) {
	case '?':
	case 'h':   print_syntax(cmdname,syntax,info); exit(0); break;
	case 'd':   debug_option = atoi(optarg); break;
	case 'H':   header_dir = optarg; break;
	case 'O':   operator = optarg; break;
	case 'D':   dcc = optarg; break;
	case 'M':   mode = optarg; break;
	case 'N':   network = strdup(optarg); break;
	case 'C':   ++contiguous_flag; break;
	case 'S':   ++short_flag; break;
	case 'A':   ++ascii_flag; break;
	case 'm':   ++multi_channel_flag; break;
	}

    /*	A null network is valid, since it implies that we use the	*/
    /*	network_id from the data file.					*/

    if (no_output) outfile = "/dev/null";
    if (outfile == NULL) info = stderr;

    /*	Skip over all options and their arguments.			*/
/*    argv = &(argv[optind]); */
    argv += optind;
    argc -= optind;

    /* The remaining arguments are the input files.			*/

    nfiles = argc;
    if (nfiles <= 0) {
	print_syntax(cmdname,syntax,info);
	exit(1);
    }

    return(0);
}
